==> naive-ui-2.11.0.tgz: package/README.md <==
<p align="center">
  <img width="144px" src="https://naiveui.oss-cn-hongkong.aliyuncs.com/naivelogo.svg" />
</p>

<h1 align="center">Naive UI</h1>
<p align="center">A Vue 3 Component Library</p>
<p align="center"><b>Fairly Complete, Customizable Themes, Uses Typescript, Not too Slow</b></p>
<p align="center">Kinda Interesting</p>

<p align="center">English | <a href="README.zh-CN.md">中文</a></p>

## Documentation

[www.naiveui.com](http://www.naiveui.com)

## Features

### Fairly Complete

There are more than 70 components. Hope they can help you write less code.

What's more, they are all treeshakable.

### Customizable Themes

We provide an advanced type safe theme system that built Uses Typescript. All you need is to provide a theme overrides object in JS. Then all the staff is done by us.

What's more, no less/sass/css variables, no webpack loaders are required.

### Uses Typescript

All the staff in Naive UI is wrote in Typescript. It can work with your typescript project seamlessly.

What's more, you don't need to import any CSS to use the components.

### Not too Slow

I try to make it not rather slow. At least select, tree, transfer, table and cascader work with virtual list.

What's more, ..., no more. Just enjoy it.

## Installation

### npm

Use npm to install.

```bash
npm i -D naive-ui
```

### Fonts

```bash
npm i -D vfonts
```

### Icons

naive-ui recommends using [xicons](https://www.xicons.org) as icon library.

### Design Resources

Sorry, currently there is nothing.

## License

Naive UI is licensed under the [MIT license](https://opensource.org/licenses/MIT).

Graphics resouces of `result` component is licensed under the [CC-BY 4.0](https://creativecommons.org/licenses/by/4.0/). The graphics resources come from [Twemoji](https://github.com/twitter/twemoji).

==> naive-ui-2.11.2.tgz: package/README.md <==
<p align="center">
  <img width="144px" src="https://naiveui.oss-cn-hongkong.aliyuncs.com/naivelogo.svg" />
</p>

<h1 align="center">Naive UI</h1>
<p align="center">A Vue 3 Component Library</p>
<p align="center"><b>Fairly Complete, Customizable Themes, Uses Typescript, Not too Slow</b></p>
<p align="center">Kinda Interesting</p>

<p align="center">English | <a href="README.zh-CN.md">中文</a></p>

## Documentation

[www.naiveui.com](http://www.naiveui.com)

## Features

### Fairly Complete

There are more than 70 components. Hope they can help you write less code.

What's more, they are all treeshakable.

### Customizable Themes

We provide an advanced type safe theme system that built Uses Typescript. All you need is to provide a theme overrides object in JS. Then all the staff is done by us.

What's more, no less/sass/css variables, no webpack loaders are required.

### Uses Typescript

All the staff in Naive UI is wrote in Typescript. It can work with your typescript project seamlessly.

What's more, you don't need to import any CSS to use the components.

### Not too Slow

I try to make it not rather slow. At least select, tree, transfer, table and cascader work with virtual list.

What's more, ..., no more. Just enjoy it.

## Installation

### npm

Use npm to install.

```bash
npm i -D naive-ui
```

### Fonts

```bash
npm i -D vfonts
```

### Icons

Naive UI recommends using [xicons](https://www.xicons.org) as icon library.

### Design Resources

Sorry, currently there is nothing.

## Community

- [Discord](https://discord.gg/Pqv7Mev5Dd)
- DingTalk Group 33482509

## License

Naive UI is licensed under the [MIT license](https://opensource.org/licenses/MIT).

Graphics resouces of `result` component is licensed under the [CC-BY 4.0](https://creativecommons.org/licenses/by/4.0/). The graphics resources come from [Twemoji](https://github.com/twitter/twemoji).
